==> dde-control-center_5.4.23.orig.tar.xz: dde-control-center-5.4.23/translations/recovery_si.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="si" version="2.1">
<context>
    <name>BackgroundWidget</name>
    <message>
        <location filename="../abrecovery/backgroundwidget.cpp" line="49"/>
        <location filename="../abrecovery/backgroundwidget.cpp" line="64"/>
        <source>Rolling back the system, please wait...</source>
        <translation>පද්ධතිය නැවත පෙර තත්වයට හරවමින් පවතී, කරුණාකර රැඳී සිටින්න...</translation>
    </message>
</context>
<context>
    <name>RecoveryDialog</name>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="259"/>
        <source>Rollback failed.</source>
        <translation>ආපසු හැරවීම අසාර්ථකයි.</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="264"/>
        <source>Reboot</source>
        <translation>පද්ධතිය නැවත අරඹන්න</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="271"/>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>%2 ‍වන දින උපස්ථ කර ඇති %1 වෙත පද්ධතිය ආපසු හැරවීමට ඔබට අවශ්‍යද?</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="274"/>
        <source>Cancel and Reboot</source>
        <translation>අවලංගු කර නැවත ආරම්භ කරන්න</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="275"/>
        <source>Confirm</source>
        <translation>තහවුරු කරන්න</translation>
    </message>
</context>
</TS>

==> dde-control-center_5.5.16.2.orig.tar.xz: dde-control-center-5.5.16.2/translations/recovery_si.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="si">
<context>
    <name>BackgroundWidget</name>
    <message>
        <location filename="../abrecovery/backgroundwidget.cpp" line="49"/>
        <location filename="../abrecovery/backgroundwidget.cpp" line="65"/>
        <source>Rolling back the system, please wait...</source>
        <translation>පද්ධතිය නැවත පෙර තත්වයට හරවමින් පවතී, කරුණාකර රැඳී සිටින්න...</translation>
    </message>
</context>
<context>
    <name>RecoveryDialog</name>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="266"/>
        <source>Rollback failed.</source>
        <translation>ආපසු හැරවීම අසාර්ථකයි.</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="271"/>
        <source>Reboot</source>
        <translation>පද්ධතිය නැවත අරඹන්න</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="280"/>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>%2 ‍වන දින උපස්ථ කර ඇති %1 වෙත පද්ධතිය ආපසු හැරවීමට ඔබට අවශ්‍යද?</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="283"/>
        <source>Cancel and Reboot</source>
        <translation>අවලංගු කර නැවත ආරම්භ කරන්න</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="284"/>
        <source>Confirm</source>
        <translation>තහවුරු කරන්න</translation>
    </message>
</context>
</TS>
